@@ -3,7 +3,7 @@ use glium::{
     IndexBuffer, Surface, VertexBuffer,
 };
 
-use super::vec2::Vec2;
+use crate::vec2::Vec2;
 
 #[derive(Copy, Clone)]
 pub struct Vertex {
@@ -26,13 +26,13 @@ pub struct Background {
 
 impl Background {
     pub fn new(display: &Display) -> Self {
-        let shape = vec![
+        let shape = [
             Vertex::new(-1.0, 1.0),
             Vertex::new(-1.0, -1.0),
             Vertex::new(1.0, 1.0),
             Vertex::new(1.0, -1.0),
         ];
-        let index_buffer: [u8; 6] = [0, 1, 2, 2, 1, 3];
+        let index_buffer = &[0, 1, 2, 2, 1, 3];
 
         Self {
             shader: Program::from_source(
@@ -43,18 +43,17 @@ impl Background {
             )
             .unwrap(),
             vertices: VertexBuffer::new(display, &shape).unwrap(),
-            indices: IndexBuffer::new(display, PrimitiveType::TrianglesList, &index_buffer)
-                .unwrap(),
+            indices: IndexBuffer::new(display, PrimitiveType::TrianglesList, index_buffer).unwrap(),
         }
     }
 
-    pub fn render(&self, target: &mut glium::Frame, size: Vec2<f32>) {
+    pub fn render(&self, target: &mut glium::Frame, size: Vec2<f32>, top_offset: f32) {
         target
             .draw(
                 &self.vertices,
                 &self.indices,
                 &self.shader,
-                &uniform! { size: *size },
+                &uniform! { size: *size, top_offset: top_offset },
                 &Default::default(),
             )
             .unwrap();
